function Y=blfwasconv(X,alfa,R,P)
%	BLFW+AS CONVERSION
%	Applies a BLFW+AS transform to a set of cepstral vectors
%
%	Y=blfwasconv(X,alpha,R,P)
%
%	Y: converted cepstral column-vectors
%
%	X: matrix of input cepstral column-vectors (without c0)
%	alpha: frequency warping factor(s) - one factor per class
%	R: amplitude scaling vector(s) - one vector per class
%	P: soft classification matrix (optional) - P(k,t) is the
%	   probability that X(:,t) belongs to class k - number of
%	   classes must be compatible with alpha and R
%
%	---------------------------------------------------
%	Copyright (c) 2013 University of the Basque Country
%	---------------------------------------------------
%	License
%	This program is free software: you can redistribute
%	it and/or modify it under the terms of the GNU General
%	Public License as published by the Free Software Foundation,
%	either version 3 of the License, or any later version.
%	This program is distributed in the hope that it will be
%	useful, but WITHOUT ANY WARRANTY; without even the implied
%	warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
%	PURPOSE. See the GNU General Public License for more details.
%	---------------------------------------------------
%	Author: Daniel Erro (derro(a)aholab.ehu.es)
%	---------------------------------------------------


[p,N]=size(X);
% if no classification specified, we assume a single alpha
% otherwise we assume compatible dimensions
if nargin<4 || isempty(P) alfa=repmat(alfa,1,N); else alfa=alfa*P; end;
% fictitious c0
X=[zeros(1,N); X];
Y=zeros(p+1,N);
% recursive formulation of BLFW
for k=0:p
	Yant=Y;
	Y(1,:)=X(p-k+1,:)+alfa.*Yant(1,:);
	Y(2,:)=(1.0-alfa.*alfa).*Yant(1,:)+alfa.*Yant(2,:);
	for kk=2:p Y(kk+1,:)=Yant(kk,:)+alfa.*(Yant(kk+1,:)-Y(kk,:)); end;
end;
Yant=[];
% remove fictitious c0
Y=Y(2:end,:);
% if no R supplied, exit
if nargin<3 || isempty(R) return; end;
% otherwise, apply AS
if nargin<4 || isempty(P) Y=Y+repmat(R,1,N); else Y=Y+R*P; end;
