function [P,L]=gmmprobs(G,X)
%	GMM PROBABILITIES
%	Calculates the probabilities that the input
%	vectors belong to each component of a GMM
%
%	[P,L]=gmmprobs(G,X)
%
%	P: matrix where P(k,t) is the probability
%	   that X(:,t) belongs to class k
%	L: global likelihood of X with respect to G
%
%	G: gmm trained by gmmtrain.m
%	X: matrix of input column-vectors
%
%	---------------------------------------------------
%	Copyright (c) 2013 University of the Basque Country
%	---------------------------------------------------
%	License
%	This program is free software: you can redistribute
%	it and/or modify it under the terms of the GNU General
%	Public License as published by the Free Software Foundation,
%	either version 3 of the License, or any later version.
%	This program is distributed in the hope that it will be
%	useful, but WITHOUT ANY WARRANTY; without even the implied
%	warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
%	PURPOSE. See the GNU General Public License for more details.
%	---------------------------------------------------
%	Author: Daniel Erro (derro(a)aholab.ehu.es)
%	---------------------------------------------------


[dim,N]=size(X);
m=length(G);
if m==1 P=ones(1,N); return; end;
P=zeros(m,N);
cte=power(2*pi,-0.5*dim);
for g=1:m
    ag=G(g).a*cte/sqrt(G(g).dE);
	Xu=X-repmat(G(g).u,1,N);
	P(g,:)=ag*exp(-0.5*sum(Xu.*(G(g).iE*Xu)));	
end;
L=sum(P,1);
P=P./repmat(L,m,1);
L=sum(log(L));
